#!/bin/bash
# store password for elastic user in variable
ELASTIC_PWD=$(kubectl get secrets -n elastic-stack elasticsearch-es-elastic-user -o jsonpath='{.data.elastic}'| tr -d '"' | base64 -d)

kubectl exec -it -n elastic-stack elasticsearch-es-default-0 -- curl -k -XPUT https://elastic:$ELASTIC_PWD@localhost:9200/_ingest/pipeline/logs-fruit_shop-default -H "Content-type: application/json" -d '
{ 
    "description": "Pipeline for fruit shop",
    "processors": 
    [
        {
            "grok": 
            {
                "field": "message",
                "patterns": 
                    [
                        "%{TIMESTAMP_ISO8601:timestamp} %{WORD:stream} %{WORD} %{IPORHOST:source_ip} %{WORD:order.status} Ordered %{INT:order.amount} of %{WORD:order.fruit}",
                        "%{TIMESTAMP_ISO8601:timestamp} %{WORD:stream} %{WORD} %{IPORHOST:source_ip} %{WORD:order.status} Tried to order %{INT:order.amount} of %{WORD:order.fruit} %{GREEDYDATA}",
                        "%{TIMESTAMP_ISO8601:timestamp} %{WORD:stream} %{WORD} %{IPORHOST:source_ip} %{WORD:restock.status} Restocked %{WORD:restock.fruit}"
                    ]
            }
        }
    ]
}'

kubectl exec -it -n elastic-stack elasticsearch-es-default-0 -- curl -k -XPUT https://elastic:$ELASTIC_PWD@localhost:9200/_component_template/logs-fruit_shop-settings -H "Content-type: application/json" -d  '
{
    "template": 
    {
        "settings": 
        {
            "index.default_pipeline": "logs-fruit_shop-default",
            "index.lifecycle.name": "logs"
        }
    }
}'

kubectl exec -it -n elastic-stack elasticsearch-es-default-0 -- curl -k -XPUT https://elastic:$ELASTIC_PWD@localhost:9200/_index_template/logs-fruit_shop-template -H "Content-type: application/json" -d '
{
    "index_patterns": ["logs-fruit_shop-*"],
    "data_stream": { },
    "priority": 500,
    "composed_of": ["logs-fruit_shop-settings"]
}' 

kubectl exec -it -n elastic-stack elasticsearch-es-default-0 -- curl -k -XPOST https://elastic:$ELASTIC_PWD@localhost:9200/logs-fruit_shop-default/_rollover/